@@ -139,6 +139,16 @@ class DeltaTableHelper:
                 storage_options=storage_options,
             )
 
+    def vaccuum_delta(self, bucket_name: str, table_name:str, retention_hours: int = 168, dry_run: bool = True):
+        if retention_hours < 168:
+            raise ValueError("Retention period must be at least 168 hours (7 days)")
+        path = f"s3://{bucket_name}/{table_name}"
+        dt = DeltaTable(path, storage_options={"AWS_REGION": AWS_REGION})
+        deleted_files = dt.vacuum(retention_hours=168, dry_run=False)
+
+        return deleted_files
+
+
 
     def _delta_table_exists(self, path: str, storage_options: Optional[dict] = None) -> bool:
         """
